C     Last change:  DLA  18 Nov 2004   11:26 am
      program WriteNji
C
C     Program WriteNji: Write Njoy input files for FENDL-2.1 Library
C                       It follows FENDL processing specifications
C                       See: INDC(NDS)-373, 1997
C                            INDC(NDS)-395, 1998
C                            IAEA(NDS)-175, Rev. 1, 98/10
C                            INDC(NDS)-451, 2003
C     Author: D. L. Aldama, IAEA Consultant
C     Date:   11/2004
C
C     Description: Reads data from an input file and writes
C                  the corresponding NJOY processing input file (NJI).
C
C     Input File Format: For each material the following data
C                        should be entered in the order below:
C     FILENAME
C     ZSYMA
C     MAT MATH
C     NSIG0
C     (SIG0(i), i=1,NSIG0)
C     MATXSID
C     ---- Blank line ---
C
C     where:
C      FILENAME(character*5): Njoy input file name (NJI file)
C      ZSYMA(CHARACTER*9): Z-SYM-A Ex. 1-H-1
C      MAT: Material Number on the Evaluated Nuclear Data File
C      MAT: Material NUmber in the Photo-atomic library
C      NSIG0: Number of SIG0 values for processing
C      SIG0(i): i-th sigma0 value (Bondarenko Sigma0 Values)
C      MATXSID: Material identification for the MATXS file.
C
C     The input file can contain more than one material. The data
C     block above should be repeated for each material
C     The input file is finished with the word EOF or with a blank
C     file name.
C
C     I/O UNITS: Input Unit=5 (standard input)
C                Ouput Unit=1
C
C     Usage: WriteNji<InputFileName
C
      character*5 FNAME,dummy5,dummy15,dummy25
      character*8 MATID
      character*9 ZSYMA, dummy9
      character*10 LIB, dummy10
      dimension sig0(10)
      read(5,*,err=10000)FNAME
      do while (FNAME(1:3).ne.'EOF' .and. FNAME.ne.'     ')
        read(5,*,err=10000)ZSYMA
        read(5,*,err=10000)MAT,MAPH
        read(5,'(a10)',err=10000)LIB
        read(5,*,err=10000)NSIG
        read(5,*,err=10000)(sig0(i),i=1,NSIG)
        read(5,*,err=10000)MATID
        read(5,*,err=10000)
        dummy5=adjustr(FNAME)
        dummy9=dummy5//'.nji'
        dummy10=adjustl(dummy9)
        open(1,file=dummy10)
          write(dummy5,'(i4)')MAT
          call strr(dummy5,imat)
          write(dummy15,'(i4)')MAPH
          call strr(dummy15,imaph)
          write(dummy25,'(i4)')NSIG
          call strr(dummy25,insig)
          call strr(LIB,ilib)
          call strr(ZSYMA,iza)
          call strr(MATID,imatid)
          write(1,'(a)')'moder / Extract/convert neutron evaluated data'
          write(1,'(a)')'1 -21'
          write(1,'(a)')''''//ZSYMA(1:iza)//' from FENDLE-2.1''/'
          write(1,'(a)')'20 '//dummy5(1:imat)
          write(1,'(a)')'0/'
          write(1,'(a)')'moder / Extract/convert photo-atomic data'
          write(1,'(a)')'1 -41'
          write(1,'(a)')
     &    ''''//ZSYMA(1:iza)//' from FENDLE photo-atomic''/'
          write(1,'(a)')'40 '//dummy15(1:imaph)
          write(1,'(a)')'0/'
          write(1,'(a)')'reconr / Reconstruct XS for neutrons'
          write(1,'(a)')'-21 -22'
          write(1,'(a)')'''FENDL-2.1 PENDF for '//ZSYMA(1:iza)//'''/'
          write(1,'(a)')dummy5(1:imat)//' 2/'
          write(1,'(a)')'0.001 0. 0.003/'
          write(1,'(a)')
     &    '''FENDL-2.1: '//ZSYMA(1:iza)//' from '//LIB(1:ilib)//'''/'
          write(1,'(a)')
     &    '''Processed by NJOY-99.90 at NDS/IAEA Nov2004''/'
          write(1,'(a)')'0/'
          write(1,'(a)')'broadr / Doppler broaden XS'
          write(1,'(a)')'-21 -22 -23'
          write(1,'(a)')dummy5(1:imat)//' 1 0 0 0./'
          write(1,'(a)')'0.001 2.0e6 0.003/'
          write(1,'(a)')'300.'
          write(1,'(a)')'0/'
          write(1,'(a)')'heatr / Add heating kerma and damage energy'
          write(1,'(a)')'-21 -23 -24/'
          write(1,'(a)')dummy5(1:imat)//' 2 0 0 0 2/'
          write(1,'(a)')'443 444/'
          write(1,'(a)')'gaspr / Add gas production'
          write(1,'(a)')'-21 -24 -25'
          write(1,'(a)')
     &    'purr / Process Unresolved Resonance Range if any'
          write(1,'(a)')'-21 -25 -26'
          write(1,'(a)')
     &    dummy5(1:imat)//' 1 '//dummy25(1:insig)//' 20 100/'
          write(1,'(a)')'300.'
          write(1,'(1p10(e6.0,1x))')(sig0(i),i=1,nsig)
          write(1,'(a)')'0/'
          write(1,'(a)')'acer / Prepare ACE files'
          write(1,'(a)')'-21 -26 0 27 28'
          write(1,'(a)')'1 0 1 .21/'
          write(1,'(a)')''''//ZSYMA(1:iza)//' from FENDL-2.1('
     &    //LIB(1:ilib)//') NJOY 99.90 NDS/IAEA Nov2004''/'
          write(1,'(a)')dummy5(1:imat)//' 300.'
          write(1,'(a)')'1 1/'
          write(1,'(a)')'/'
          write(1,'(a)')'acer / Check ACE files'
          write(1,'(a)')'0 27 0 29 30'
          write(1,'(a)')'7 1 1 -1/'
          write(1,'(a)')'/'
          write(1,'(a)')'groupr / Prepare multigroup data for neutrons'
          write(1,'(a)')'-21 -26 0 31'
          WRITE(1,'(a)')
     &    dummy5(1:imat)//' 17 10 11 6 1 '//dummy25(1:insig)//' 1/'
          write(1,'(a)')''''//ZSYMA(1:iza)//' from FENDL-2.1('
     &    //LIB(1:ilib)//') NJOY 99.90 NDS/IAEA Nov2004''/'
          write(1,'(a)')'300.'
          write(1,'(1p10(e6.0,1x))')(sig0(i),i=1,nsig)
          write(1,'(a)')'3/'
          write(1,'(a)')'3  251 ''mubar''/'
          write(1,'(a)')'3  252 ''xi''/'
          write(1,'(a)')'3  253 ''gamma''/'
          write(1,'(a)')'3  259 ''1/v''/'
          if (ZSYMA(1:iza).eq.'4-Be-9'.and.
     &        LIB(1:ilib).eq.'JEFF-3.0') then
            write(1,'(a)')'6  2/'
            write(1,'(a)')'8  875/'
            write(1,'(a)')'8 -890/'
          else
            write(1,'(a)')'6/'
          endif
          write(1,'(a)')'16/'
          write(1,'(a)')'0/'
          write(1,'(a)')'0/'
          write(1,'(a)')'reconr / Reconstruct photo-atomic data'
          write(1,'(a)')'-41 -42'
          write(1,'(a)')'''FENDL-2.1 photo-atomic PENDF TAPE for '
     &    //ZSYMA(1:iza)//'''/'
          write(1,'(a)')dummy15(1:imaph)//' 2/'
          write(1,'(a)')'0.001 0. 0.003/'
          write(1,'(a)')'''FENDL-2.1: '//ZSYMA(1:iza)//
     &    ' from ENDF/B-VI''/'
          write(1,'(a)')
     &    '''Processed by NJOY-99.90 at NDS/IAEA Nov2004''/'
          write(1,'(a)')'0/'
          write(1,'(a)')'gaminr / Prepare multigroup data for photons'
          write(1,'(a)')'-41 -42 0 43/'
          write(1,'(a)')dummy15(1:imaph)//' 10 3 6 1/'
          write(1,'(a)')
     &    ''''//ZSYMA(1:iza)//
     &    ' from FENDL-2.1(ENDF/B-VI) NJOY-99.90 NDS/IAEA Nov2004''/'
          write(1,'(a)')'-1/'
          write(1,'(a)')'0/'
          write(1,'(a)')'matxsr / Produce MATXS file'
          write(1,'(a)')'31 43 44/'
          write(1,'(a)')'1 ''fendl-2.1 '//MATID(1:imatid)//'''/'
          write(1,'(a)')'2 3 3 1'
          write(1,'(a)')'''FENDL-2.1: '//ZSYMA(1:iza)
     &    //' from '//LIB(1:ilib)//'''/'
          write(1,'(a)')'''Photo-atomic data from ENDF/B-VI''/'
          write(1,'(a)')
     &    '''Processed by NJOY-99.90 at NDS/IAEA Nov2004''/'
          write(1,'(a)')'''n'' ''g''/'
          write(1,'(a)')'175 42'
          write(1,'(a)')'''nscat'' ''ng'' ''gscat''/'
          write(1,'(a)')'1 1 2/'
          write(1,'(a)')'1 2 2/'
          write(1,'(a)')''''//MATID(1:imatid)//''' '
     &    //dummy5(1:imat)//' '//dummy15(1:imaph)//'/'
          write(1,'(a)')'stop'
          close(1)
        read(5,*,err=10000)FNAME
      end do
10000 stop
      end
      subroutine strr(a,n)
        character*(*) a
        character*80 b
        b=a
        a=adjustl(b)
        n=len_trim(a)
        return
      end
